#!/usr/bin/perl
use strict;
use warnings;
use Test::More tests => 4;

use_ok('Kwiki::Template::TT2::UTF8');
require_ok ('Kwiki::Template::TT2::UTF8');

use_ok('Kwiki::Template::TT2::UTF8::Provider');
require_ok ('Kwiki::Template::TT2::UTF8::Provider');

